PcsVerifierTranscript

Struct PcsVerifierTranscript 

pub struct PcsVerifierTranscript {
    pub fs_transcript: Blake3Transcript,
    pub stream: Cursor<Vec<u8>>,
}
Version of [PcsProverTranscript] used for proof verification.

Fields

fs_transcript: Blake3Transcript

Handles Fiat-Shamir transformations for non-interactive zero-knowledge proofs. Used to absorb field elements and generate cryptographic challenges.

stream: Cursor<Vec<u8>>

Manages serialization and deserialization of proof data as a byte stream.

Implementations

Source

impl PcsVerifierTranscript

pub fn squeeze_challenge_idx(&mut self, cap: usize) -> usize

Generates a pseudorandom index based on the current transcript state. Used to create deterministic challenges for zero-knowledge protocols. Returns an index between 0 and cap-1.

pub fn read_field_elements<F>(&mut self, n: usize) -> Result<Vec<F>, ZipError>
where F: PrimeField, F::Inner: Transcribable, F::Modulus: Transcribable,

pub fn read<T: Transcribable>(&mut self) -> Result<T, ZipError>

pub fn read_const_many<T: ConstTranscribable>( &mut self, n: usize, ) -> Result<Vec<T>, ZipError>

pub fn read_merkle_proof(&mut self) -> Result<MerkleProof, ZipError>